# Lightning Network BOLT12 Routines

This is a simple Python 3 library to read, check, generate and
manipulate [BOLT 12](https://bolt12.org) offers, invoice_requests and
invoices.

See [examples/](examples/) for usage.
